@@ -10,12 +10,20 @@ import mutagen
 
 needs_sphinx = "1.3"
 
-extensions = ['sphinx.ext.autodoc', 'sphinx.ext.intersphinx', 'ext']
-intersphinx_mapping = {'python': ('http://docs.python.org/2.7', None)}
+extensions = [
+    'sphinx.ext.autodoc',
+    'sphinx.ext.napoleon',
+    'sphinx.ext.intersphinx',
+    'ext',
+]
+intersphinx_mapping = {
+    'python': ('https://docs.python.org/2.7', None),
+    'python3': ('https://docs.python.org/3.5', None),
+}
 source_suffix = '.rst'
 master_doc = 'index'
 project = 'mutagen'
-copyright = u'2014, Joe Wreschnig, Michael Urman, Lukáš Lalinský, ' \
+copyright = u'2016, Joe Wreschnig, Michael Urman, Lukáš Lalinský, ' \
             u'Christoph Reiter, Ben Ockmore & others'
 version = mutagen.version_string
 release = mutagen.version_string
@@ -28,3 +36,7 @@ autodoc_member_order = "bysource"
 default_role = "obj"
 
 html_theme = "sphinx_rtd_theme"
+html_favicon = "images/favicon.ico"
+html_theme_options = {
+    "display_version": False,
+}
