@@ -7,6 +7,9 @@ import glob
 import os
 import sys
 import unittest
+import warnings
+import shutil
+from tempfile import mkstemp
 
 from unittest import TestCase as BaseTestCase
 
@@ -28,6 +31,30 @@ if os.name != "nt":
                            "Try setting LANG=C.UTF-8")
 
 
+# Make sure we see all deprecation warnings so we either have to avoid them
+# or capture them in the test suite
+warnings.simplefilter("always")
+warnings.simplefilter("ignore", PendingDeprecationWarning)
+
+
+def get_temp_copy(path):
+    """Returns a copy of the file with the same extension"""
+
+    ext = os.path.splitext(path)[-1]
+    fd, filename = mkstemp(suffix=ext)
+    os.close(fd)
+    shutil.copy(path, filename)
+    return filename
+
+
+def get_temp_empty(ext=""):
+    """Returns an empty file with the extension"""
+
+    fd, filename = mkstemp(suffix=ext)
+    os.close(fd)
+    return filename
+
+
 class TestCase(BaseTestCase):
 
     def failUnlessRaisesRegexp(self, exc, re_, fun, *args, **kwargs):
@@ -47,6 +74,9 @@ class TestCase(BaseTestCase):
     failUnlessAlmostEqual = BaseTestCase.assertAlmostEqual
     failIfEqual = BaseTestCase.assertNotEqual
     failIfAlmostEqual = BaseTestCase.assertNotAlmostEqual
+    assertEquals = BaseTestCase.assertEqual
+    assertNotEquals = BaseTestCase.assertNotEqual
+    assert_ = BaseTestCase.assertTrue
 
     def assertReallyEqual(self, a, b):
         self.assertEqual(a, b)
