@@ -1,9 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import os
-import shutil
-from tempfile import mkstemp
-from tests import TestCase, DATA_DIR
+import warnings
 
 from mutagen._compat import PY3, text_type, PY2, izip, cBytesIO
 from mutagen.asf import ASF, ASFHeaderError, ASFValue, UNICODE, DWORD, QWORD
@@ -17,6 +15,8 @@ from mutagen.asf import ASFUnicodeAttribute, ASFError, ASFByteArrayAttribute, \
     ASFBoolAttribute, ASFDWordAttribute, ASFQWordAttribute, ASFWordAttribute, \
     ASFGUIDAttribute
 
+from tests import TestCase, DATA_DIR, get_temp_copy
+
 
 class TASFFile(TestCase):
 
@@ -101,9 +101,7 @@ class TASFInfo(TestCase):
 class TASF(TestCase):
 
     def setUp(self):
-        fd, self.filename = mkstemp(suffix='wma')
-        os.close(fd)
-        shutil.copy(self.original, self.filename)
+        self.filename = get_temp_copy(self.original)
         self.audio = ASF(self.filename)
 
     def tearDown(self):
@@ -431,9 +429,7 @@ class TASFIssue29(TestCase):
     original = os.path.join(DATA_DIR, "issue_29.wma")
 
     def setUp(self):
-        fd, self.filename = mkstemp(suffix='wma')
-        os.close(fd)
-        shutil.copy(self.original, self.filename)
+        self.filename = get_temp_copy(self.original)
         self.audio = ASF(self.filename)
 
     def tearDown(self):
@@ -460,7 +456,9 @@ class TASFObjects(TestCase):
     filename = os.path.join(DATA_DIR, "silence-1.wma")
 
     def test_invalid_header(self):
-        asf = ASF()
+        with warnings.catch_warnings():
+            warnings.simplefilter("ignore")
+            asf = ASF()
         fileobj = cBytesIO(
             b"0&\xb2u\x8ef\xcf\x11\xa6\xd9\x00\xaa\x00b\xcel\x19\xbf\x01\x00"
             b"\x00\x00\x00\x00\x07\x00\x00\x00\x01\x02")
@@ -473,9 +471,7 @@ class TASFAttrDest(TestCase):
     original = os.path.join(DATA_DIR, "silence-1.wma")
 
     def setUp(self):
-        fd, self.filename = mkstemp(suffix='wma')
-        os.close(fd)
-        shutil.copy(self.original, self.filename)
+        self.filename = get_temp_copy(self.original)
         audio = ASF(self.filename)
         audio.clear()
         audio.save()
@@ -551,9 +547,7 @@ class TASFLargeValue(TestCase):
     original = os.path.join(DATA_DIR, "silence-1.wma")
 
     def setUp(self):
-        fd, self.filename = mkstemp(suffix='wma')
-        os.close(fd)
-        shutil.copy(self.original, self.filename)
+        self.filename = get_temp_copy(self.original)
 
     def tearDown(self):
         os.unlink(self.filename)
@@ -608,9 +602,7 @@ class TASFSave(TestCase):
     original = os.path.join(DATA_DIR, "silence-1.wma")
 
     def setUp(self):
-        fd, self.filename = mkstemp(suffix='.wma')
-        os.close(fd)
-        shutil.copy(self.original, self.filename)
+        self.filename = get_temp_copy(self.original)
         self.audio = ASF(self.filename)
 
     def tearDown(self):
